package koeln.uni.idh.java1.session11;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.nio.file.AccessDeniedException;

public class ExceptionDemo2 {

	public static void main(String[] args) {
		ExceptionDemo2 ed = new ExceptionDemo2();
		// run the program
		ed.start();
	}

	public void start() {
		System.out.println("This little tool shows the contents of a file.");
		// We first annoy the user by asking them for a meaningless confirmation
		System.out.println("Press Y to continue.");
		try {
			char ch = (char) System.in.read();
			if (ch == 'Y' || ch == 'y') {
				// we read in a second character, because user has pressed enter after the Y
				// The newline character needs to be consumed
				System.in.read();
				mainloop();
			}
		} catch (IOException e) {
			System.out.println("Could not read from input. Exiting now.");
			System.exit(1);
		}
	}

	void mainloop() {
		try {
			String fn = getFilename("Please enter a file name");
			showFile(fn);
		} catch (FileNotFoundException e) {
			System.out.println("File not found. Try again.");
			mainloop();
		} catch (AccessDeniedException e) {
			System.out.println("No access to the file. Try another file.");
			mainloop();
		} catch (IOException e) {
			System.out.println("Other IO error. Exiting.");
		}
	}

	void showFile(String filename) throws IOException {
		FileInputStream fis = new FileInputStream(filename);
		InputStreamReader reader = new InputStreamReader(fis, "UTF-8");
		int content = reader.read();
		while (content > 0) {
			System.out.print((char) content);
			content = reader.read();
		}
		reader.close();
	}

	String getFilename(String prompt) {
		String r = null;
		while (r == null) {
			System.out.println(prompt);
			BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
			try {
				r = in.readLine();
			} catch (IOException e) {
				System.out.println("An error occurred: " + e.getLocalizedMessage());
				System.out.println("Please try again.");
			}
		}
		return r;
	}

}
